package com.example.planovac_v1.app;

import android.app.Activity;
import android.database.Cursor;
import android.os.Bundle;
import android.view.ContextMenu;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.AdapterView;
import android.widget.Button;
import android.widget.EditText;
import android.widget.ListView;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;

public class MainActivity extends Activity implements View.OnClickListener {
    private ArrayList<polozka_zoznamu> zoznam_poloziek;
    private ListView m_zoznam;
    private adapter_poloziek_zoznamu apz;
    private EditText m_datum;
    private EditText m_text;
    private Button m_tlacidlo;

    // pre pracu s dB
    adapter_dB m_dB;

    // obsah kontextoveho menu
    static final private int REMOVE_ITEM = Menu.FIRST;
    static final private int REMOVE_ALL_ITEMS = Menu.FIRST + 1;

    // zaciatok zivotneho cyklu aktivity
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        // spristupnenie UI widgetov definovanych v XML layoute activity_main.xml
        m_datum = (EditText)findViewById(R.id.datum);
        m_text = (EditText)findViewById(R.id.text);
        m_tlacidlo = (Button)findViewById(R.id.tlacidlo);
        m_zoznam = (ListView)findViewById(R.id.zoznam);

        // vytvorenie zoznamu poloziek
        zoznam_poloziek = new ArrayList<polozka_zoznamu>();
        // vytvorenie adapteru pre prepojenie zoznamu poloziek s UI widgetom ListView
        apz = new adapter_poloziek_zoznamu(this, R.layout.polozka, zoznam_poloziek);
        // nastavenie adapteru pre UI widget ListView
        m_zoznam.setAdapter(apz);
        // kontextove menu pre ListView
        registerForContextMenu(m_zoznam);

        // reakcia tlacidla na kliknutie myskou
        m_tlacidlo.setOnClickListener(this);

        // pre pracu s dB
        m_dB = new adapter_dB(this);
        // vytvorenie, alebo otvorenie dB
        m_dB.open();
        // aktualizacia zoznamu poloziek na zaklade udajov z dB
        aktualizuj_zoznam_poloziek();
    }
    // koniec zivotneho cyklu aktivity
    @Override
    public void onDestroy(){
        // zatvorenie dB
        m_dB.close();
        super.onDestroy();
    }
    // reakcia tlacidla na kliknutie myskou
    public void onClick(View view) {
        // konverzia String na Date
        SimpleDateFormat sdf = new SimpleDateFormat("dd.MM.yy");
        Date convertedDate = new Date();
        try {
            convertedDate = sdf.parse(m_datum.getText().toString());
        } catch (ParseException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        }
        // vytvorenie novej polozky zoznamu
        polozka_zoznamu NP = new polozka_zoznamu(convertedDate, m_text.getText().toString());
        // pridanie polozky do dB
        m_dB.pridaj_zaznam(NP);
        // aktualizacia zoznamu poloziek na zaklade udajov z dB
        aktualizuj_zoznam_poloziek();
        // vymazanie obsahu UI widgetu m_text
        m_text.setText("");
    }
    // aktualizacia zoznamu poloziek na zaklade udajov z dB
    private void aktualizuj_zoznam_poloziek() {
        // vymazanie zoznamu poloziek
        zoznam_poloziek.clear();

        // kurzor na vsetky zaznamy
        Cursor kurzor_zaznamu = m_dB.kurzor_na_vsetky_zaznamy();

        // pre vsetky riadky tabulky
        if (kurzor_zaznamu.moveToFirst())
            do {
                // nacitanie datumu
                long d = kurzor_zaznamu.getLong(adapter_dB.COLUMN_DATE_NUM);
                // nacitanie ulohy
                String u = kurzor_zaznamu.getString(adapter_dB.COLUMN_TASK_NUM);
                // vytvorenie novej polozky zoznamu
                polozka_zoznamu NP = new polozka_zoznamu(new Date(d), u);
                // pridanie polozky do zoznamu poloziek
                zoznam_poloziek.add(0, NP);
            } while(kurzor_zaznamu.moveToNext());

        // zatvorenie kurzoru
        kurzor_zaznamu.close();

        // aktualizacia adapteru pre UI widget ListView
        apz.notifyDataSetChanged();
    }
    // kontextove menu pre ListView
    @Override
    public void onCreateContextMenu(ContextMenu menu,
                                    View v,
                                    ContextMenu.ContextMenuInfo menuInfo) {
        super.onCreateContextMenu(menu, v, menuInfo);
        menu.setHeaderTitle(R.string.zoznam);
        menu.add(0, REMOVE_ITEM, Menu.NONE, R.string.vymaz_polozku);
        menu.add(0, REMOVE_ALL_ITEMS, Menu.NONE, R.string.vymaz_vsetky_polozky);
    }
    // reakcia na vyber v ramci kontextoveho menu
    @Override
    public boolean onContextItemSelected(MenuItem item) {
        super.onContextItemSelected(item);
        switch (item.getItemId()) {
            case (REMOVE_ITEM): {
                AdapterView.AdapterContextMenuInfo menuInfo;
                menuInfo =(AdapterView.AdapterContextMenuInfo)item.getMenuInfo();
                // pozicia polozky v ramci ListView = v ramci zoznamu_poloziek
                int index = menuInfo.position;
                // vymazanie zaznamu z tabulky dB na zaklade znenia ulohy
                m_dB.vymaz_zaznam(zoznam_poloziek.get(index).get_uloha());
                // aktualizacia zoznamu poloziek
                aktualizuj_zoznam_poloziek();
                return true;
            }
            case (REMOVE_ALL_ITEMS): {
                // vymazanie vsetkych zaznamov z tabulky dB
                m_dB.vymaz_vsetky_zaznamy();
                // aktualizacia zoznamu poloziek
                aktualizuj_zoznam_poloziek();
                return true;
            }
        }
        return false;
    }
}